"""
    signalsdb
    ~~~~~~~~~

    Python library providing a simple way to query a
    curated database of Unix signals.

    :copyright: (c) 2015 Eeo Jun
    :license: MIT, see LICENSE for details.
"""

__version__ = '0.1'
